@@ -4,12 +4,14 @@ from multiprocessing import cpu_count
 # gdal config
 gdal.SetConfigOption("SHAPE_ENCODING", 'utf-8')
 gdal.PushErrorHandler('CPLQuietErrorHandler')
+gdal.SetConfigOption("GDAL_FILENAME_IS_UTF8", "YES")
+gdal.SetConfigOption("GDAL_NUM_THREADS", "ALL_CPUS")
 
 # cpu used
 N_CPU = max(cpu_count() - 1, 1)
 
 # default spatial reference system
-WGS84 = "+proj=longlat +datum=WGS84 +ellps=WGS84"
+WGS84 = "EPSG:4326"
 
 # creation options
 CREATION = ['BIGTIFF=YES', 'TILED=YES', 'NUM_THREADS=ALL_CPUS',
